import { useNavigate } from "react-router-dom";
import { useEffect } from "react";
import { Hub } from "aws-amplify";

import Router from "./routes";
import ThemeProvider from "./theme";
import NotistackProvider from "./components/NotistackProvider";
import { Auth } from "./Authenticator";

export default function App() {
  const navigate = useNavigate();

  useEffect(() => {
    const handleAuthChange = (data: { payload?: { event?: string } }) => {
      try {
        if (data?.payload?.event === "signIn") {
          navigate("/contacts/all");
          window.location.reload();
        } else if (data?.payload?.event === "signOut") {
          navigate("/");
        }
      } catch (error) {
        console.error("Error handling authentication change:", error);
      }
    };

    const removeAuthListener = Hub.listen("auth", handleAuthChange);

    return () => {
      removeAuthListener();
    };
  }, [navigate]);

  return (
    <ThemeProvider>
      <NotistackProvider>
        <Auth>
          <Router />
        </Auth>
      </NotistackProvider>
    </ThemeProvider>
  );
}
