import { Authenticator, Theme, ThemeProvider } from "@aws-amplify/ui-react";
import "@aws-amplify/ui-react/styles.css";
import { ReactNode } from "react";
import styled from "@emotion/styled";

import palette from "./theme/palette";
import Logo from "./components/Logo";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";

type Props = {
  children: ReactNode;
};

const CenteredAuthenticator = styled(Authenticator)`
  display: flex;
  justify-content: center;
  align-items: center;
  height: 90vh;
`;

export function Auth({ children }: Props) {
  const theme: Theme = {
    name: "Auth Theme",
    tokens: {
      colors: {
        font: {
          interactive: {
            value: palette.light.primary.main,
          },
        },
        brand: {
          primary: {
            "80": palette.light.primary.main,
            "90": palette.light.primary.light,
          },
        },
      },
      components: {
        tabs: {
          item: {
            _focus: {
              color: {
                value: palette.light.primary.main,
              },
            },
            _hover: {
              color: {
                value: palette.light.primary.main,
              },
            },
            _active: {
              color: {
                value: palette.light.primary.main,
              },
            },
          },
        },
      },
    },
  };

  return (
    <ThemeProvider theme={theme}>
      <Box
        sx={{
          p: 2,
          display: "flex",
          flexDirection: "row-reverse",
        }}
      >
        <Logo />
        <Box
          sx={{
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            pr: 1,
          }}
        >
          <Typography variant="h6">Contacts App</Typography>
        </Box>
      </Box>
      <CenteredAuthenticator>{children}</CenteredAuthenticator>
    </ThemeProvider>
  );
}
