import { api } from "../api";
import {
  createContactApi,
  deleteSingleContactApi,
  getAllContactApi,
  getAllContactsWithSpecificLabelApi,
  getListOfFavoriteContactApi,
  getSingleContactApi,
  getTotalCountContactApi,
  getTotalCountForContactLabelApi,
  getTotalCountForFavoriteContactApi,
  updateIsFavoriteStatusContactApi,
  updateSingleContactApi,
  batchDeleteContactApi,
} from "./contactService";

const contactsApiEndpoints = api.injectEndpoints({
  endpoints: (build) => ({
    createContact: build.mutation({
      queryFn: createContactApi,
      invalidatesTags: ["Contacts"],
    }),
    getAllContacts: build.query({
      queryFn: getAllContactApi,
      providesTags: ["Contacts"],
    }),
    getAllContactsWithSpecificLabel: build.query({
      queryFn: getAllContactsWithSpecificLabelApi,
      providesTags: ["Contacts"],
    }),
    getListOfFavoriteContacts: build.query({
      queryFn: getListOfFavoriteContactApi,
      providesTags: ["Contacts"],
    }),
    getSingleContact: build.query({
      queryFn: getSingleContactApi,
      providesTags: ["Contacts"],
    }),
    getTotalCountContacts: build.query({
      queryFn: getTotalCountContactApi,
      providesTags: ["Contacts"],
    }),
    getTotalCountForFavoriteContacts: build.query({
      queryFn: getTotalCountForFavoriteContactApi,
      providesTags: ["Contacts"],
    }),
    getTotalCountForContactLabel: build.query({
      queryFn: getTotalCountForContactLabelApi,
      providesTags: ["Contacts"],
    }),
    updateSingleContact: build.mutation({
      queryFn: updateSingleContactApi,
      invalidatesTags: ["Contacts"],
    }),
    updateIsFavoriteStatusContact: build.mutation({
      queryFn: updateIsFavoriteStatusContactApi,
      invalidatesTags: ["Contacts"],
    }),
    deleteSingleContact: build.mutation({
      queryFn: deleteSingleContactApi,
      invalidatesTags: ["Contacts"],
    }),
    batchDeleteContact: build.mutation({
      queryFn: batchDeleteContactApi,
      invalidatesTags: ["Contacts"],
    }),
  }),
});

export const {
  useCreateContactMutation,
  useGetAllContactsQuery,
  useGetSingleContactQuery,
  useUpdateSingleContactMutation,
  useDeleteSingleContactMutation,
  useUpdateIsFavoriteStatusContactMutation,
  useGetListOfFavoriteContactsQuery,
  useGetTotalCountContactsQuery,
  useGetTotalCountForFavoriteContactsQuery,
  useGetAllContactsWithSpecificLabelQuery,
  useGetTotalCountForContactLabelQuery,
  useBatchDeleteContactMutation,
} = contactsApiEndpoints;
