import { FetchBaseQueryError } from "@reduxjs/toolkit/query";
import { API } from "aws-amplify";

import { Label, UnsavedLabel } from "types/labels";

export async function createLabelApi(
  newLabel: UnsavedLabel
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.post("contactAPI", "/label", {
      body: newLabel,
    });
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function getAllLabelApi(): Promise<
  { data: Label[] } | { error: FetchBaseQueryError }
> {
  try {
    const data = await API.get("contactAPI", "/label", {});
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function deleteSingleLabelApi(
  labelId: string
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.del(
      "contactAPI",
      `/label/remove-label/${labelId}`,
      {}
    );
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}
