import { useEffect, useState } from "react";
import { useSnackbar } from "notistack";
import { useNavigate } from "react-router-dom";
import Card from "@mui/material/Card";
import Typography from "@mui/material/Typography";
import Stack from "@mui/material/Stack";
import TextField from "@mui/material/TextField";
import Modal from "@mui/material/Modal";
import Button from "@mui/material/Button";
import LoadingButton from "@mui/lab/LoadingButton";

import { useCreateLabelMutation } from "../api/label/labelApi";
import { UnsavedLabel } from "../types/labels";
import { CONTACTS_ROUTES } from "../routes/paths";
import firstCharToUpperCase from "../utils/firstCharToUpperCase";

interface Props {
  isOpen: boolean;
  handleClose: () => void;
}

export default function LabelModal({ isOpen, handleClose }: Props) {
  const navigate = useNavigate();
  const { enqueueSnackbar } = useSnackbar();
  const [labelName, setLabelName] = useState<string>("");

  const [createLabel, { data, isError, error, isLoading }] =
    useCreateLabelMutation();

  const handleCreate = () => {
    const newLabel: UnsavedLabel = {
      name: firstCharToUpperCase(labelName),
    };

    createLabel(newLabel);
  };

  useEffect(() => {
    if (data) {
      enqueueSnackbar(`You have successfully created a label `, {
        variant: "success",
      });
      navigate(`${CONTACTS_ROUTES.all}`);
      handleClose();
    }
  }, [data]);

  useEffect(() => {
    if (error || isError) {
      enqueueSnackbar("Failed to create label", { variant: "error" });
    }
  }, [data]);

  useEffect(() => {
    return () => {
      setLabelName("");
    };
  }, []);

  return (
    <Modal
      open={isOpen}
      aria-labelledby="modal-modal-title"
      aria-describedby="modal-modal-description"
      onClose={handleClose}
    >
      <Card
        sx={{
          position: "relative",
          alignItems: "center",
          top: "50%",
          left: "50%",
          transform: "translate(-50%, -50%)",
          width: "500px",
          padding: "20px",
          borderBottom: "solid 20px white",
        }}
      >
        <Stack gap={2}>
          <Typography id="modal-modal-title" variant="h6" component="h2">
            Create label
          </Typography>
          <TextField
            id="outlined-basic"
            label="Enter label name"
            variant="outlined"
            fullWidth
            value={labelName}
            onChange={(e) => setLabelName(e.target.value)}
          />
          <Stack direction="row" justifyContent="flex-end" gap={1}>
            <Button onClick={handleClose} variant="outlined">
              Cancel
            </Button>
            <LoadingButton
              loading={isLoading}
              variant="contained"
              onClick={() => handleCreate()}
            >
              Save
            </LoadingButton>
          </Stack>
        </Stack>
      </Card>
    </Modal>
  );
}
