import { useSnackbar } from "notistack";
import { useEffect } from "react";
import { useNavigate } from "react-router-dom";

import Page from "components/Page";
import { UnsavedContact } from "types/contacts";
import { CONTACTS_ROUTES } from "routes/paths";
import { useCreateContactMutation } from "api/contact/contactApi";

import ContactForm from "./ContactForm";

export default function CreateContact() {
  const navigate = useNavigate();
  const { enqueueSnackbar } = useSnackbar();

  const [createContact, { data, isError, error, isLoading }] =
    useCreateContactMutation();

  console.log("isLoafing", isLoading);

  const handleCreate = async (value: UnsavedContact) => {
    const newContact: UnsavedContact = {
      name: value.name,
      image: value.image,
      email: value.email,
      phone: value.phone,
      isFavorite: 0,
      labels: value.labels,
    };

    createContact(newContact);
  };

  useEffect(() => {
    if (data) {
      enqueueSnackbar(`You have successfully created a contact `, {
        variant: "success",
      });
      navigate(`${CONTACTS_ROUTES.all}`);
    }
  }, [data]);

  useEffect(() => {
    if (error || isError) {
      enqueueSnackbar("Failed to create contact", { variant: "error" });
    }
  }, [data]);

  return (
    <Page title="Create new contact">
      <ContactForm
        title="Create new contact"
        onSubmit={handleCreate}
        isLoading={isLoading}
      />
    </Page>
  );
}
