import { useEffect } from "react";
import { useParams } from "react-router-dom";
import { useSnackbar } from "notistack";
import { useNavigate } from "react-router-dom";
import { skipToken } from "@reduxjs/toolkit/dist/query/react";

import Page from "components/Page";
import {
  useGetSingleContactQuery,
  useUpdateSingleContactMutation,
} from "api/contact/contactApi";
import { Contact, UnsavedContact } from "types/contacts";
import LoadingScreen from "components/LoadingScreen";
import { CONTACTS_ROUTES } from "routes/paths";

import ContactForm from "./ContactForm";

export default function EditContact() {
  const { id } = useParams();
  const navigate = useNavigate();
  const { enqueueSnackbar } = useSnackbar();
  const { data, isLoading } = useGetSingleContactQuery(id ?? skipToken);
  const [
    updateSingleContact,
    { data: editedContact, error, isError, isLoading: isLoadingEdit },
  ] = useUpdateSingleContactMutation();

  const handleEdit = (value: UnsavedContact) => {
    if (!data) return;

    const updateContact: Contact = {
      ...data,
      name: value.name,
      phone: value.phone,
      image: value.image,
      email: value.email,
      labels: value.labels,
    };

    updateSingleContact(updateContact);
  };

  useEffect(() => {
    if (editedContact) {
      enqueueSnackbar(`You have successfully edited a contact `, {
        variant: "success",
      });
      navigate(`${CONTACTS_ROUTES.all}`);
    }
  }, [editedContact]);

  useEffect(() => {
    if (error || isError) {
      enqueueSnackbar("Failed to edit contact", { variant: "error" });
    }
  }, [editedContact]);

  return (
    <>
      {isLoading ? (
        <LoadingScreen />
      ) : (
        <Page title="Edit contact">
          <ContactForm
            title="Edit contact"
            isLoading={isLoadingEdit}
            key={data?.contactId}
            onSubmit={handleEdit}
            value={data}
          />
        </Page>
      )}
    </>
  );
}
