import { lazy, useEffect, useState } from "react";
import { useRoutes, Navigate, useNavigate } from "react-router-dom";
import { useAuthenticator } from "@aws-amplify/ui-react";

import DashboardLayout from "../layouts/mainLayout";
import NotFound from "../components/NotFound";

import { Loadable } from "./Loadable";

export default function Router() {
  const { user } = useAuthenticator((context) => [context.user]);

  const privateRoutes = [
    {
      path: "/",
      element: <DashboardLayout />,
      children: [
        {
          path: "/",
          element: <Navigate to="contacts/all" replace />,
        },
        {
          path: "contacts/all",
          element: <ContactsList />,
        },
        {
          path: "contacts/favorites",
          element: <ContactsList />,
        },
        {
          path: "contacts/labels/*",
          element: <ContactsList />,
        },
        {
          path: "contacts/new_contact",
          element: <CreateNewContact />,
        },
        {
          path: "contacts/edit_contact/:id",
          element: <EditContact />,
        },
      ],
    },
    {
      path: "*",
      element: <NotFound />,
      children: [
        { path: "404", element: <NotFound /> },
        { path: "*", element: <Navigate to="/404" replace /> },
      ],
    },
    { path: "*", element: <Navigate to="/404" replace /> },
  ];

  const publicRoutes = [
    {
      path: "*",
      element: <NotFound />,
      children: [
        { path: "404", element: <NotFound /> },
        { path: "*", element: <Navigate to="/404" replace /> },
      ],
    },
    { path: "*", element: <Navigate to="/404" replace /> },
  ];

  // Determine which set of routes to use based on the user's authentication status
  const routes = user ? privateRoutes : publicRoutes;

  return useRoutes(routes);
}

const ContactsList = Loadable(lazy(() => import("../pages/contactsList")));
const CreateNewContact = Loadable(
  lazy(() => import("../pages/contactsForm/CreateContact"))
);
const EditContact = Loadable(
  lazy(() => import("../pages/contactsForm/EditContact"))
);
